package Hypernova;
use strict;
use warnings;

our $VERSION = 0.02; # TRIAL

=pod

=head1 NAME

Hypernova - Perl Hypernova Client (for rendering React components)

=head1 SYNOPSIS

	# Make a Renderer
	use Hypernova::Renderer;

	my $renderer = Hypernova::Renderer->new('http://localhost:3030/batch');
	
	#Give it some work:
	$renderer->addJob(myViewId => {name => 'my_module_name', data => {some => ['props']} });

	# Add plugins
	# see Hypernova::Plugin
	$renderer->addPlugin($myPlugin);
	$renderer->addPlugin($myOtherPlugin);

	# Get your rendered Response:
	my $response = $renderer->render();

=head1 NOTICE

No useful code here yet, stay tuned

=head1 SEE ALSO

Hypernova: L<https://github.com/airbnb/hypernova>

Hypernova-PHP: L<https://github.com/wayfair/hypernova-php>



=head1 AUTHOR
	
James Wright <jwright@cpan.org>

=head1 COPYRIGHT

Copyright 2017, The L</AUTHOR> as listed above.

=head1 LICENSE

This library is free software and may be distributed under the same terms
as perl itself. See L<http://dev.perl.org/licenses/>.

=cut

1;
